powered by
Internal function to read the meta data repository (MDR).
read_mdr(utils_path = NULL, mdr_filename = "mdr.csv")
A data.table containing the metadata repository which is imported from the CSV file provided with {utils_path}/MDR/{mdr_filename}.
{utils_path}/MDR/{mdr_filename}
A character string. The path to the utils-folder, containing the required app utilities like the MDR and the settings folder.
A character string. The filename of your meta data repository (default: 'mdr.csv').
utils_path <- system.file( "demo_data/utilities/", package = "DQAstats" ) mdr_filename <- "mdr_example_data.csv" mdr <- read_mdr( utils_path = utils_path, mdr_filename = mdr_filename )
Run the code above in your browser using DataLab